@@ -4,9 +4,7 @@ use strict;
 use warnings;
 
 BEGIN
-  { our
-      $VERSION = substr '$$Version: 0.04 $$', 11, -3;
-  }
+  { our $VERSION = substr '$$Version: 0.05 $$', 11, -3;  }
 
 require Exporter;
 
@@ -23,7 +21,7 @@ sub modifiable : lvalue
 
     for my $i (0..$#_)
       {	($m = $i, last) if defined $_[$i] && !readonly $_[$i]; }
-    $_[$m];
+    $m >= 0 ? $_[$m] : $_;
   }
 
 1;
