@@ -5,9 +5,7 @@ use strict;
 use warnings;
 
 BEGIN
-  { our
-      $VERSION = substr '$$Version: 0.04 $$', 11, -3;
-  }
+  { our $VERSION = substr '$$Version: 0.05 $$', 11, -3; }
 
 require Exporter;
 
